//  This Source Code Form is subject to the terms of the Mozilla Public
//  License, v. 2.0. If a copy of the MPL was not distributed with this
//  file, You can obtain one at http://mozilla.org/MPL/2.0/.

part of 'verve.dart';

///An opinionated, simplified Card with curved corners.
Container verveCard({@required Widget child}) {
  return Container(
      padding: EdgeInsets.symmetric(vertical: 2.5, horizontal: 20.0),
      decoration: new BoxDecoration(
        shape: BoxShape.rectangle,
        borderRadius: new BorderRadius.circular(5.0),
      ),
      child: Card(
        child: Container(child: child, margin: EdgeInsets.symmetric(vertical: 7.5)),
      ));
}

///An opinionated, simplified Button with curved corners.
RaisedButton verveButton(
    {@required VoidCallback onPressed, @required Widget child}) {
  return RaisedButton(
    shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(10.0)),
    onPressed: onPressed,
    child: child,
  );
}

///A generator for ListViews. Takes in two lists of Strings and returns a ListView
///of verveCards. The [titles] list is displayed as titles within the cards and the
///[subtitles] list is displayed as subtitles.
ListView verveListView(
    {@required List<String> titles, @required List<String> subtitles}) {
  if (titles.length != subtitles.length)
    throw ArgumentError('Titles and values must be the same length.');
  return ListView.builder(
    itemCount: subtitles.length,
    shrinkWrap: true,
    itemBuilder: (BuildContext context, int i) {
      return verveCard(
          child: Column(children: <Widget>[
            Text(titles[i], style: Theme.of(context).textTheme.title.copyWith(color: Colors.black)),
            Text(subtitles[i], style: Theme.of(context).textTheme.subtitle.copyWith(color: Colors.black)),
      ]));
    },
  );
}

/// An opinionated, simplified FlatButton.icon with rounded corners.
///
/// Can be used in place of IconButton.
FlatButton verveIconButton(
    {@required VoidCallback onPressed,
    @required IconData icon,
    Text label = const Text('')}) {
  return FlatButton.icon(
    onPressed: onPressed,
    icon: Icon(icon),
    label: label,
    shape: RoundedRectangleBorder(
      borderRadius: new BorderRadius.circular(8.0),
    ),
  );
}
